import { createRouter, createWebHashHistory } from 'vue-router'
import Home from '../views/Home/Home.vue'

const routes = [
  {
    path: '/',
    redirect: '/monitor/home'
  },
  {
    path: '/monitor/home', // 驾驶舱
    name: 'Home',
    component: Home,
  },
  {
    path: '/monitor/about',
    name: 'About',
    component: () => import(/* webpackChunkName: "about" */ '../views/About.vue'),
  },
  {
    path: '/monitor/status', // 状态监视
    name: 'Status',
    component: () => import(/* webpackChunkName: "status" */ '../views/Status/Status.vue'),
  },
  {
    path: '/monitor/agc', // AGC 监视
    name: 'Agc',
    component: () => import(/* webpackChunkName: "agc" */ '../views/Agc/Agc.vue'),
  },
  {
    path: '/monitor/windsite',
    name: 'WindSite',
    component: () => import(/* webpackChunkName: "windsite" */ '../views/WindSite/WindSite.vue'),
    children: [{
      path: 'home/:wpId',  // 场站监视
      component: () => import(/* webpackChunkName: "windsitehome" */ '../views/WindSite/pages/Home/Home.vue'),
    }, {
      path: 'draughtfanlist/:wpId', // 风机列表
      component: () => import(/* webpackChunkName: "windsitedraughtfanlist" */ '../views/WindSite/pages/DraughtFanList.vue'),
    }, {
      path: 'matrix/:wpId', // 风场矩阵
      component: () => import(/* webpackChunkName: "windsitematrix" */ '../views/WindSite/pages/Matrix.vue'),
    }, {
      path: 'lightmatrix/:wpId',
      component: () => import(/* webpackChunkName: "windsitelightmatrix" */ '../views/WindSite/pages/LightMatrix.vue'),
    }, {
      path: 'box/:wpId',
      component: () => import(/* webpackChunkName: "windsitebox" */ '../views/WindSite/pages/Box.vue'),
    }, {
      path: 'info/:wpId/:wtId', // 单机状态监视
      component: () => import(/* webpackChunkName: "info" */ '../views/WindSite/pages/Info/Info.vue'),
    }, {
      path: 'tower/:wpId', // 测风塔
      component: () => import(/* webpackChunkName: "windsitetower" */ '../views/WindSite/pages/Tower.vue'),
    }, {
      path: 'inverter-info/:wpId',
      component: () => import(/* webpackChunkName: "inverter-info" */ '../views/WindSite/pages/Inverter-Info.vue'),
    }, {
      path: 'map/:wpId',
      component: () => import(/* webpackChunkName: "windsitemap" */ '../views/WindSite/pages/Map.vue'),
    }, {
      path: 'map1/:wpId',
      component: () => import(/* webpackChunkName: "windsitemap1" */ '../views/WindSite/pages/Map1.vue'),
    },{
      path: 'boosterstation', // AGC 监视
      component: () => import(/* webpackChunkName: "boosterstation" */ '../views/WindSite/pages/BoosterStation.vue'),
    },]
  },
  {
    path: '/monitor/lightmatrix', // 光伏明细矩阵
    name: 'LightMatrix',
    component: () => import(/* webpackChunkName: "lightmatrix" */ '../views/LightMatrix/LightMatrix.vue'),
  },
  {
    path: '/monitor/lightmatrix1', // 基础矩阵
    name: 'LightMatrix1',
    component: () => import(/* webpackChunkName: "lightmatrix1" */ '../views/LightMatrix1/LightMatrix1.vue'),
  },
  {
    path: '/monitor/lightmatrix2', // 欠发矩阵
    name: 'LightMatrix2',
    component: () => import(/* webpackChunkName: "lightmatrix2" */ '../views/LightMatrix2/LightMatrix2.vue'),
  }, {
    path: '/monitor/lightmatrix3', // 明细矩阵
    name: 'LightMatrix3',
    component: () => import(/* webpackChunkName: "lightmatrix3" */ '../views/LightMatrix3/LightMatrix3.vue'),
  }, {
    path: '/decision/decision1',
    name: 'decision1',
    component: () => import(/* webpackChunkName: "decision1" */ '../views/Decision/Decision1.vue'),
  },
  {
    path: '/decision/decision2',
    name: 'decision2',
    component: () => import(/* webpackChunkName: "decision2" */ '../views/Decision/Decision2.vue'),
  },
  {
    path: '/decision/decision3',
    name: 'decision3',
    component: () => import(/* webpackChunkName: "decision3" */ '../views/Decision/Decision3.vue'),
  },
  {
    path: '/decision/decision4',
    name: 'decision4',
    component: () => import(/* webpackChunkName: "decision4" */ '../views/Decision/Decision4.vue'),
  },
  {
    path: '/health',
    name: 'health',
    component: () => import('../views/HealthControl/Health.vue'),
  },
  {
    path: '/health/health1',
    name: 'health1',
    component: () => import('../views/HealthControl/Health1.vue'),
  },
  {
    path: '/health/health2', // 健康管理首页
    name: 'health2',
    component: () => import('../views/HealthControl/Health2.vue'),
  },
  {
    path: '/health/health3/:wpId',
    name: 'health3',
    component: () => import('../views/HealthControl/Health3.vue'),
  },
  {
    path: '/health/health4',
    name: 'health4',
    component: () => import('../views/HealthControl/Health4.vue'),
  },
  {
    path: '/health/health5',
    name: 'health5',
    component: () => import('../views/HealthControl/Health5.vue'),
  },
  {
    path: '/health/health6',
    name: 'health6',
    component: () => import('../views/HealthControl/Health6.vue'),
  },
  {
    path: '/health/health7',
    name: 'health7',
    component: () => import('../views/HealthControl/Health7.vue'),
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  base: '/zhfx/',
  routes
})

router.beforeEach((to, from, next) => {
  next()
})

export default router
